@@ -9,7 +9,7 @@ use fields qw( buffer buffered from subject to );
 
 use vars qw[ $VERSION ];
 
-$VERSION = sprintf "%d.%02d", q$Revision: 1.15 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.16 $ =~ /: (\d+)\.(\d+)/;
 
 1;
 
@@ -20,11 +20,7 @@ sub new
 
     my %params = @_;
 
-    my $self;
-    {
-	no strict 'refs';
-	$self = bless [ \%{"${class}::FIELDS"} ], $class;
-    }
+    my $self = bless {}, $class;
 
     $self->_basic_init(%params);
 
@@ -43,7 +39,7 @@ sub new
 
 sub log_message
 {
-    my Log::Dispatch::Email $self = shift;
+    my $self = shift;
     my %params = @_;
 
     if ($self->{buffered})
@@ -66,7 +62,7 @@ sub send_email
 
 sub flush
 {
-    my Log::Dispatch::Email $self = shift;
+    my $self = shift;
 
     if ($self->{buffered} && @{ $self->{buffer} })
     {
@@ -79,7 +75,7 @@ sub flush
 
 sub DESTROY
 {
-    my Log::Dispatch::Email $self = shift;
+    my $self = shift;
 
     $self->flush;
 }
@@ -100,7 +96,7 @@ via email
 
   sub send_email
   {
-      my Log::Dispatch::Email::MySender $self = shift;
+      my $self = shift;
       my %params = @_;
 
       # Send email somehow.  Message is in $params{message}
