@@ -11,13 +11,13 @@ use Mail::Sendmail ();
 
 use vars qw[ $VERSION ];
 
-$VERSION = sprintf "%d.%02d", q$Revision: 1.14 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.15 $ =~ /: (\d+)\.(\d+)/;
 
 1;
 
 sub send_email
 {
-    my Log::Dispatch::Email::MailSendmail $self = shift;
+    my $self = shift;
     my %params = @_;
 
     my %mail = ( To      => (join ',', @{ $self->{to} }),
