@@ -9,7 +9,7 @@ use fields qw( fh filename );
 
 use vars qw[ $VERSION ];
 
-$VERSION = sprintf "%d.%02d", q$Revision: 1.16 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.17 $ =~ /: (\d+)\.(\d+)/;
 
 # Prevents death later on if IO::File can't export this constant.
 BEGIN
@@ -31,11 +31,7 @@ sub new
 
     my %params = @_;
 
-    my $self;
-    {
-	no strict 'refs';
-	$self = bless [ \%{"${class}::FIELDS"} ], $class;
-    }
+    my $self = bless {}, $class;
 
     $self->_basic_init(%params);
     $self->_make_handle(%params);
@@ -45,7 +41,7 @@ sub new
 
 sub _make_handle
 {
-    my Log::Dispatch::File $self = shift;
+    my $self = shift;
     my %params = @_;
 
     $self->{filename} = $params{filename};
@@ -76,7 +72,7 @@ sub _make_handle
 
 sub log_message
 {
-    my Log::Dispatch::File $self = shift;
+    my $self = shift;
     my %params = @_;
 
     my $fh = $self->{fh};
