@@ -9,7 +9,7 @@ use fields qw( stderr );
 
 use vars qw[ $VERSION ];
 
-$VERSION = sprintf "%d.%02d", q$Revision: 1.13 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.15 $ =~ /: (\d+)\.(\d+)/;
 
 1;
 
@@ -19,21 +19,17 @@ sub new
     my $class = ref $proto || $proto;
     my %params = @_;
 
-    my $self;
-    {
-	no strict 'refs';
-	$self = bless [ \%{"${class}::FIELDS"} ], $class;
-    }
+    my $self = bless {}, $class;
 
     $self->_basic_init(%params);
-    $self->{stderr} = $params{stderr} if $params{stderr};
+    $self->{stderr} = exists $params{stderr} ? $params{stderr} : 1;
 
     return $self;
 }
 
 sub log_message
 {
-    my Log::Dispatch::Screen $self = shift;
+    my $self = shift;
     my %params = @_;
 
     if ($self->{stderr})
@@ -42,7 +38,7 @@ sub log_message
     }
     else
     {
-	print $params{message};
+	print STDOUT $params{message};
     }
 }
 
