@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..122\n"; }
+BEGIN { $| = 1; print "1..123\n"; }
 END {print "not ok 1\n" unless $main::loaded;}
 
 use strict;
@@ -443,7 +443,7 @@ Screen:
     undef $f1;
 
     open F, '<./write_mode.tst'
-	or die "Cannot read ./write_mode.tst: $!";
+	or die "Cannot read ./wr_mode.tst: $!";
     my $data = join '', <F>;
     close F;
 
